@@ -205,6 +205,9 @@ enum {
 	FUNCTION_ID_NORM = 1138,
 	FUNCTION_ID_VERTCAT = 1139,
 	FUNCTION_ID_HORZCAT = 1140,
+	FUNCTION_ID_KRONECKER_PRODUCT = 1141,
+	FUNCTION_ID_COLON = 1142,
+	FUNCTION_ID_FLIP = 1143,
 	FUNCTION_ID_SQRT = 1200,
 	FUNCTION_ID_CBRT = 1201,
 	FUNCTION_ID_ROOT = 1202,
@@ -317,6 +320,9 @@ enum {
 	FUNCTION_ID_IS_INTEGER = 1923,
 	FUNCTION_ID_ODD = 1924,
 	FUNCTION_ID_EVEN = 1925,
+	FUNCTION_ID_INTEGER_DIGITS = 1930,
+	FUNCTION_ID_DIGIT_GET = 1931,
+	FUNCTION_ID_DIGIT_SET = 1932,
 	FUNCTION_ID_POLYNOMIAL_UNIT = 2000,
 	FUNCTION_ID_POLYNOMIAL_PRIMPART = 2001,
 	FUNCTION_ID_POLYNOMIAL_CONTENT = 2002,
@@ -330,8 +336,12 @@ enum {
 	FUNCTION_ID_BIT_CMP = 2102,
 	FUNCTION_ID_SHIFT = 2103,
 	FUNCTION_ID_CIRCULAR_SHIFT = 2104,
+	FUNCTION_ID_BIT_SET = 2105,
+	FUNCTION_ID_BIT_GET = 2106,
+	FUNCTION_ID_SET_BITS = 2107,
 	FUNCTION_ID_FOR = 2150,
 	FUNCTION_ID_IF = 2151,
+	FUNCTION_ID_FOREACH = 2152,
 	FUNCTION_ID_TOTAL = 2200,
 	FUNCTION_ID_PERCENTILE = 2201,
 	FUNCTION_ID_MIN = 2202,
@@ -393,6 +403,7 @@ DECLARE_BUILTIN_FUNCTION(VectorFunction, FUNCTION_ID_VECTOR)
 DECLARE_BUILTIN_FUNCTION(LimitsFunction, FUNCTION_ID_LIMITS)
 DECLARE_BUILTIN_FUNCTION(RankFunction, FUNCTION_ID_RANK)
 DECLARE_BUILTIN_FUNCTION(SortFunction, FUNCTION_ID_SORT)
+DECLARE_BUILTIN_FUNCTION(FlipFunction, FUNCTION_ID_FLIP)
 DECLARE_BUILTIN_FUNCTION_M(ComponentFunction, FUNCTION_ID_COMPONENT)
 DECLARE_BUILTIN_FUNCTION_PI(DimensionFunction, FUNCTION_ID_DIMENSION)
 DECLARE_BUILTIN_FUNCTION(MatrixFunction, FUNCTION_ID_MATRIX)
@@ -419,6 +430,7 @@ DECLARE_BUILTIN_FUNCTION(EntrywiseFunction, FUNCTION_ID_ENTRYWISE)
 DECLARE_BUILTIN_FUNCTION(LoadFunction, FUNCTION_ID_LOAD)
 DECLARE_BUILTIN_FUNCTION(ExportFunction, FUNCTION_ID_EXPORT)
 DECLARE_BUILTIN_FUNCTION(GenerateVectorFunction, FUNCTION_ID_GENERATE_VECTOR)
+DECLARE_BUILTIN_FUNCTION(ColonFunction, FUNCTION_ID_COLON)
 DECLARE_BUILTIN_FUNCTION(SelectFunction, FUNCTION_ID_SELECT)
 DECLARE_BUILTIN_FUNCTION(ProcessFunction, FUNCTION_ID_PROCESS)
 DECLARE_BUILTIN_FUNCTION(ProcessMatrixFunction, FUNCTION_ID_PROCESS_MATRIX)
@@ -429,6 +441,7 @@ DECLARE_BUILTIN_FUNCTION(EntrywiseMultiplicationFunction, FUNCTION_ID_ENTRYWISE_
 DECLARE_BUILTIN_FUNCTION(EntrywiseDivisionFunction, FUNCTION_ID_ENTRYWISE_DIVISION)
 DECLARE_BUILTIN_FUNCTION(EntrywisePowerFunction, FUNCTION_ID_ENTRYWISE_POWER)
 DECLARE_BUILTIN_FUNCTION(NormFunction, FUNCTION_ID_NORM)
+DECLARE_BUILTIN_FUNCTION_MT(KroneckerProductFunction, FUNCTION_ID_KRONECKER_PRODUCT)
 
 DECLARE_BUILTIN_FUNCTION_R(SqrtFunction, FUNCTION_ID_SQRT)
 DECLARE_BUILTIN_FUNCTION(CbrtFunction, FUNCTION_ID_CBRT)
@@ -484,19 +497,19 @@ DECLARE_BUILTIN_FUNCTION_R2(IGammaFunction, FUNCTION_ID_I_GAMMA)
 DECLARE_BUILTIN_FUNCTION(IncompleteBetaFunction, FUNCTION_ID_INCOMPLETE_BETA)
 DECLARE_BUILTIN_FUNCTION(InverseIncompleteBetaFunction, FUNCTION_ID_INVERSE_INCOMPLETE_BETA)
 
-DECLARE_BUILTIN_FUNCTION(DeriveFunction, FUNCTION_ID_DIFFERENTIATE)
-DECLARE_BUILTIN_FUNCTION(IntegrateFunction, FUNCTION_ID_INTEGRATE)
-DECLARE_BUILTIN_FUNCTION(LimitFunction, FUNCTION_ID_LIMIT)
-DECLARE_BUILTIN_FUNCTION(MonteCarloFunction, FUNCTION_ID_MONTE_CARLO)
-DECLARE_BUILTIN_FUNCTION(RombergFunction, FUNCTION_ID_ROMBERG)
+DECLARE_BUILTIN_FUNCTION_MT(DeriveFunction, FUNCTION_ID_DIFFERENTIATE)
+DECLARE_BUILTIN_FUNCTION_MT(IntegrateFunction, FUNCTION_ID_INTEGRATE)
+DECLARE_BUILTIN_FUNCTION_MT(LimitFunction, FUNCTION_ID_LIMIT)
+DECLARE_BUILTIN_FUNCTION_MT(MonteCarloFunction, FUNCTION_ID_MONTE_CARLO)
+DECLARE_BUILTIN_FUNCTION_MT(RombergFunction, FUNCTION_ID_ROMBERG)
 
-DECLARE_BUILTIN_FUNCTION(SumFunction, FUNCTION_ID_SUM)
-DECLARE_BUILTIN_FUNCTION(ProductFunction, FUNCTION_ID_PRODUCT)
-DECLARE_BUILTIN_FUNCTION(SolveFunction, FUNCTION_ID_SOLVE)
-DECLARE_BUILTIN_FUNCTION(SolveMultipleFunction, FUNCTION_ID_SOLVE_MULTIPLE)
-DECLARE_BUILTIN_FUNCTION(DSolveFunction, FUNCTION_ID_D_SOLVE)
-DECLARE_BUILTIN_FUNCTION(NewtonRaphsonFunction, FUNCTION_ID_NEWTON_RAPHSON)
-DECLARE_BUILTIN_FUNCTION(SecantMethodFunction, FUNCTION_ID_SECANT_METHOD)
+DECLARE_BUILTIN_FUNCTION_MT(SumFunction, FUNCTION_ID_SUM)
+DECLARE_BUILTIN_FUNCTION_MT(ProductFunction, FUNCTION_ID_PRODUCT)
+DECLARE_BUILTIN_FUNCTION_MT(SolveFunction, FUNCTION_ID_SOLVE)
+DECLARE_BUILTIN_FUNCTION_MT(SolveMultipleFunction, FUNCTION_ID_SOLVE_MULTIPLE)
+DECLARE_BUILTIN_FUNCTION_MT(DSolveFunction, FUNCTION_ID_D_SOLVE)
+DECLARE_BUILTIN_FUNCTION_MT(NewtonRaphsonFunction, FUNCTION_ID_NEWTON_RAPHSON)
+DECLARE_BUILTIN_FUNCTION_MT(SecantMethodFunction, FUNCTION_ID_SECANT_METHOD)
 
 DECLARE_BUILTIN_FUNCTION_R(FactorialFunction, FUNCTION_ID_FACTORIAL)
 DECLARE_BUILTIN_FUNCTION_R(DoubleFactorialFunction, FUNCTION_ID_DOUBLE_FACTORIAL)
@@ -546,6 +559,10 @@ DECLARE_BUILTIN_FUNCTION(RomanFunction, FUNCTION_ID_ROMAN)
 DECLARE_BUILTIN_FUNCTION(BijectiveFunction, FUNCTION_ID_BIJECTIVE)
 DECLARE_BUILTIN_FUNCTION(BinaryDecimalFunction, FUNCTION_ID_BINARY_DECIMAL)
 
+DECLARE_BUILTIN_FUNCTION(IntegerDigitsFunction, FUNCTION_ID_INTEGER_DIGITS)
+DECLARE_BUILTIN_FUNCTION(DigitGetFunction, FUNCTION_ID_DIGIT_GET)
+DECLARE_BUILTIN_FUNCTION(DigitSetFunction, FUNCTION_ID_DIGIT_SET)
+
 DECLARE_BUILTIN_FUNCTION(IEEE754FloatFunction, FUNCTION_ID_IEEE754_FLOAT)
 DECLARE_BUILTIN_FUNCTION(IEEE754FloatBitsFunction, FUNCTION_ID_IEEE754_FLOAT_BITS)
 DECLARE_BUILTIN_FUNCTION(IEEE754FloatComponentsFunction, FUNCTION_ID_IEEE754_FLOAT_COMPONENTS)
@@ -571,11 +588,15 @@ DECLARE_BUILTIN_FUNCTION(LDegreeFunction, FUNCTION_ID_L_DEGREE)
 DECLARE_BUILTIN_FUNCTION(BitXorFunction, FUNCTION_ID_BIT_XOR)
 DECLARE_BUILTIN_FUNCTION_B(XorFunction, FUNCTION_ID_XOR)
 DECLARE_BUILTIN_FUNCTION(BitCmpFunction, FUNCTION_ID_BIT_CMP)
+DECLARE_BUILTIN_FUNCTION(BitSetFunction, FUNCTION_ID_BIT_SET)
+DECLARE_BUILTIN_FUNCTION(BitGetFunction, FUNCTION_ID_BIT_GET)
+DECLARE_BUILTIN_FUNCTION(SetBitsFunction, FUNCTION_ID_SET_BITS)
 DECLARE_BUILTIN_FUNCTION(ShiftFunction, FUNCTION_ID_SHIFT)
 DECLARE_BUILTIN_FUNCTION(CircularShiftFunction, FUNCTION_ID_CIRCULAR_SHIFT)
 
 DECLARE_BUILTIN_FUNCTION(ForFunction, FUNCTION_ID_FOR)
 DECLARE_BUILTIN_FUNCTION_M(IFFunction, FUNCTION_ID_IF)
+DECLARE_BUILTIN_FUNCTION(ForEachFunction, FUNCTION_ID_FOREACH)
 
 DECLARE_BUILTIN_FUNCTION(TotalFunction, FUNCTION_ID_TOTAL)
 DECLARE_BUILTIN_FUNCTION(PercentileFunction, FUNCTION_ID_PERCENTILE)
