@@ -263,6 +263,8 @@ class Number {
 		bool bitXor(const Number &o);
 		bool bitNot();
 		bool bitCmp(unsigned int bits);
+		bool bitSet(unsigned long bit, bool set = true);
+		int bitGet(unsigned long bit) const;
 		bool bitEqv(const Number &o);
 		bool shiftLeft(const Number &o);
 		bool shiftRight(const Number &o);
@@ -275,6 +277,7 @@ class Number {
 		Number integer() const;
 		bool isRational() const;
 		bool isReal() const;
+		bool isNonInteger() const;
 		bool isFraction() const;
 		bool isZero() const;
 		bool isNonZero() const;
@@ -425,6 +428,7 @@ class Number {
 		bool isqrt();
 		bool isPerfectSquare() const;
 		bool round(bool halfway_to_even = true);
+		bool round(RoundingMode mode);
 		bool floor();
 		bool ceil();
 		bool trunc();
@@ -471,6 +475,7 @@ class Number {
 		bool erf();
 		bool erfi();
 		bool erfc();
+		bool erfinv();
 		bool besselj(const Number &o);
 		bool bessely(const Number &o);
 
@@ -498,6 +503,7 @@ class Number {
 
 		bool polylog(const Number &o);
 		bool igamma(const Number &o);
+		bool betainc(const Number &p, const Number &q, bool regularized = true);
 		bool fresnels();
 		bool fresnelc();
 		bool expint();
@@ -534,4 +540,10 @@ std::ostream& operator << (std::ostream &os, const Number&);
 
 bool testComplexZero(const Number *this_nr, const Number *i_nr);
 
+unsigned int standard_expbits(unsigned int bits);
+int from_float(Number &nr, std::string sbin, unsigned int bits, unsigned int expbits = 0);
+std::string to_float(Number nr, unsigned int bits, unsigned int expbits = 0, bool *approx = NULL);
+int from_float(Number &nr, std::string sbin, unsigned int bits, unsigned int expbits, unsigned int sgnpos);
+std::string to_float(Number nr, unsigned int bits, unsigned int expbits, unsigned int sgnpos, bool *approx = NULL);
+
 #endif
